==> u%2B%2B_5.0.1.orig.tar.gz: u++-5.0.1/src/examples/IO/ServerINET2.cc <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1999
// 
// ServerINET2.cc -- Server for INET/datagram socket test. Server reads data
// from multiple clients. The server reads the data from the client and writes
// it back.
// 
// Author           : Peter A. Buhr
// Created On       : Thu Apr 29 16:02:50 1999
// Last Modified By : Peter A. Buhr
// Last Modified On : Sun Aug  8 17:10:50 2004
// Update Count     : 23
// 

#include <uC++.h>
#include <uSocket.h>
#include <uIOStream.h>

#define EOD '\377'
#define BufferSize (8 * 1024)

uTask reader {
    uSocketServer &server;

    void main() {
		uDuration timeout( 10, 0 );						// timeout for read
        char buf[BufferSize];
		int len;

		try {
			for ( ;; ) {
				len = server.recvfrom( buf, sizeof(buf), 0, &timeout );
				// uCerr << uAcquire << "Server::reader read len:" << len << endl << uRelease;
				server.sendto( buf, len );				// write byte back to client
			} // for
		} catch( uSocketServer::uReadTimeout ) {
		} // try
    } // reader::main
  public:
    reader( uSocketServer &server ) : server( server ) {
    } // reader::reader
}; // reader

void uMain::main() {
	switch ( argc ) {
	  case 1:
		break;
	  default:
		uCerr << "Usage: " << argv[0] << endl;
		uExit( -1 );
	} // switch

	short unsigned int port;
	uSocketServer server( &port, SOCK_DGRAM );			// create and bind a server socket to free port

	uCout << port << endl;								// print out free port for clients
	{
		reader rd( server );							// execute until EOD
	}
} // uMain

// Local Variables: //
// tab-width: 4 //
// compile-command: "u++-work -o Server ServerINET2.cc" //
// End: //

==> u%2B%2B_5.3.0.orig.tar.gz: u++-5.3.0/src/examples/IO/ServerINET2.cc <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1999
// 
// ServerINET2.cc -- Server for INET/datagram socket test. Server reads data
// from multiple clients. The server reads the data from the client and writes
// it back.
// 
// Author           : Peter A. Buhr
// Created On       : Thu Apr 29 16:02:50 1999
// Last Modified By : Peter A. Buhr
// Last Modified On : Sat Aug  6 18:11:09 2005
// Update Count     : 30
// 

#include <uC++.h>
#include <uSocket.h>
#include <iostream>
using std::cout;
using std::cerr;
using std::osacquire;
using std::endl;

#define EOD '\377'
#define BufferSize (8 * 1024)

_Task reader {
    uSocketServer &server;

    void main() {
		uDuration timeout( 10, 0 );						// timeout for read
        char buf[BufferSize];
		int len;

		try {
			for ( ;; ) {
				len = server.recvfrom( buf, sizeof(buf), 0, &timeout );
				// osacquire( cerr ) << "Server::reader read len:" << len << endl;
			  if ( len == 0 ) uAbort( "(uSocketServer &)0x%p : EOF ecountered without EOD", &server );
				server.sendto( buf, len );				// write byte back to client
			} // for
		} catch( uSocketServer::ReadTimeout ) {
		} // try
    } // reader::main
  public:
    reader( uSocketServer &server ) : uBaseTask( 64000 ), server( server ) {
    } // reader::reader
}; // reader

void uMain::main() {
	switch ( argc ) {
	  case 1:
		break;
	  default:
		cerr << "Usage: " << argv[0] << endl;
		uExit( -1 );
	} // switch

	short unsigned int port;
	uSocketServer server( &port, SOCK_DGRAM );			// create and bind a server socket to free port

	cout << port << endl;								// print out free port for clients
	{
		reader rd( server );							// execute until EOD
	}
} // uMain

// Local Variables: //
// tab-width: 4 //
// compile-command: "u++-work -o Server ServerINET2.cc" //
// End: //
